==> netgen_occt-0.0.1.dev0-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_occt-0.0.1.dev0.data/data/lib/cmake/opencascade/OpenCASCADEApplicationFrameworkTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKCAF" for configuration "Release"
set_property(TARGET TKCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKCAF )
list(APPEND _cmake_import_check_files_for_TKCAF "${_IMPORT_PREFIX}/./libTKCAF.so.7.8.2" )

# Import target "TKCDF" for configuration "Release"
set_property(TARGET TKCDF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKCDF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKCDF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKCDF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKCDF )
list(APPEND _cmake_import_check_files_for_TKCDF "${_IMPORT_PREFIX}/./libTKCDF.so.7.8.2" )

# Import target "TKLCAF" for configuration "Release"
set_property(TARGET TKLCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKLCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKLCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKLCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKLCAF )
list(APPEND _cmake_import_check_files_for_TKLCAF "${_IMPORT_PREFIX}/./libTKLCAF.so.7.8.2" )

# Import target "TKVCAF" for configuration "Release"
set_property(TARGET TKVCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKVCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKVCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKVCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKVCAF )
list(APPEND _cmake_import_check_files_for_TKVCAF "${_IMPORT_PREFIX}/./libTKVCAF.so.7.8.2" )

# Import target "TKBin" for configuration "Release"
set_property(TARGET TKBin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBin PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKBin.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBin.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBin )
list(APPEND _cmake_import_check_files_for_TKBin "${_IMPORT_PREFIX}/./libTKBin.so.7.8.2" )

# Import target "TKBinL" for configuration "Release"
set_property(TARGET TKBinL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBinL PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKBinL.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBinL.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBinL )
list(APPEND _cmake_import_check_files_for_TKBinL "${_IMPORT_PREFIX}/./libTKBinL.so.7.8.2" )

# Import target "TKBinTObj" for configuration "Release"
set_property(TARGET TKBinTObj APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBinTObj PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKBinTObj.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBinTObj.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBinTObj )
list(APPEND _cmake_import_check_files_for_TKBinTObj "${_IMPORT_PREFIX}/./libTKBinTObj.so.7.8.2" )

# Import target "TKStd" for configuration "Release"
set_property(TARGET TKStd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKStd PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKStd.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKStd.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKStd )
list(APPEND _cmake_import_check_files_for_TKStd "${_IMPORT_PREFIX}/./libTKStd.so.7.8.2" )

# Import target "TKXml" for configuration "Release"
set_property(TARGET TKXml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXml PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKXml.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXml.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXml )
list(APPEND _cmake_import_check_files_for_TKXml "${_IMPORT_PREFIX}/./libTKXml.so.7.8.2" )

# Import target "TKXmlL" for configuration "Release"
set_property(TARGET TKXmlL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXmlL PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKXmlL.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXmlL.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXmlL )
list(APPEND _cmake_import_check_files_for_TKXmlL "${_IMPORT_PREFIX}/./libTKXmlL.so.7.8.2" )

# Import target "TKXmlTObj" for configuration "Release"
set_property(TARGET TKXmlTObj APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXmlTObj PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKXmlTObj.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXmlTObj.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXmlTObj )
list(APPEND _cmake_import_check_files_for_TKXmlTObj "${_IMPORT_PREFIX}/./libTKXmlTObj.so.7.8.2" )

# Import target "TKStdL" for configuration "Release"
set_property(TARGET TKStdL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKStdL PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKStdL.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKStdL.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKStdL )
list(APPEND _cmake_import_check_files_for_TKStdL "${_IMPORT_PREFIX}/./libTKStdL.so.7.8.2" )

# Import target "TKTObj" for configuration "Release"
set_property(TARGET TKTObj APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKTObj PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/./libTKTObj.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKTObj.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKTObj )
list(APPEND _cmake_import_check_files_for_TKTObj "${_IMPORT_PREFIX}/./libTKTObj.so.7.8.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> netgen_occt-0.0.5-py3-none-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_occt-0.0.5.data/data/lib/cmake/opencascade/OpenCASCADEApplicationFrameworkTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "TKCAF" for configuration "Release"
set_property(TARGET TKCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKCAF )
list(APPEND _cmake_import_check_files_for_TKCAF "${_IMPORT_PREFIX}/lib/libTKCAF.so.7.8.2" )

# Import target "TKCDF" for configuration "Release"
set_property(TARGET TKCDF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKCDF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKCDF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKCDF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKCDF )
list(APPEND _cmake_import_check_files_for_TKCDF "${_IMPORT_PREFIX}/lib/libTKCDF.so.7.8.2" )

# Import target "TKLCAF" for configuration "Release"
set_property(TARGET TKLCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKLCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKLCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKLCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKLCAF )
list(APPEND _cmake_import_check_files_for_TKLCAF "${_IMPORT_PREFIX}/lib/libTKLCAF.so.7.8.2" )

# Import target "TKVCAF" for configuration "Release"
set_property(TARGET TKVCAF APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKVCAF PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKVCAF.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKVCAF.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKVCAF )
list(APPEND _cmake_import_check_files_for_TKVCAF "${_IMPORT_PREFIX}/lib/libTKVCAF.so.7.8.2" )

# Import target "TKBin" for configuration "Release"
set_property(TARGET TKBin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBin PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKBin.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBin.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBin )
list(APPEND _cmake_import_check_files_for_TKBin "${_IMPORT_PREFIX}/lib/libTKBin.so.7.8.2" )

# Import target "TKBinL" for configuration "Release"
set_property(TARGET TKBinL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBinL PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKBinL.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBinL.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBinL )
list(APPEND _cmake_import_check_files_for_TKBinL "${_IMPORT_PREFIX}/lib/libTKBinL.so.7.8.2" )

# Import target "TKBinTObj" for configuration "Release"
set_property(TARGET TKBinTObj APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKBinTObj PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKBinTObj.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKBinTObj.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKBinTObj )
list(APPEND _cmake_import_check_files_for_TKBinTObj "${_IMPORT_PREFIX}/lib/libTKBinTObj.so.7.8.2" )

# Import target "TKStd" for configuration "Release"
set_property(TARGET TKStd APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKStd PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKStd.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKStd.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKStd )
list(APPEND _cmake_import_check_files_for_TKStd "${_IMPORT_PREFIX}/lib/libTKStd.so.7.8.2" )

# Import target "TKXml" for configuration "Release"
set_property(TARGET TKXml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXml PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKXml.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXml.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXml )
list(APPEND _cmake_import_check_files_for_TKXml "${_IMPORT_PREFIX}/lib/libTKXml.so.7.8.2" )

# Import target "TKXmlL" for configuration "Release"
set_property(TARGET TKXmlL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXmlL PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKXmlL.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXmlL.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXmlL )
list(APPEND _cmake_import_check_files_for_TKXmlL "${_IMPORT_PREFIX}/lib/libTKXmlL.so.7.8.2" )

# Import target "TKXmlTObj" for configuration "Release"
set_property(TARGET TKXmlTObj APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKXmlTObj PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKXmlTObj.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKXmlTObj.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKXmlTObj )
list(APPEND _cmake_import_check_files_for_TKXmlTObj "${_IMPORT_PREFIX}/lib/libTKXmlTObj.so.7.8.2" )

# Import target "TKStdL" for configuration "Release"
set_property(TARGET TKStdL APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKStdL PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKStdL.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKStdL.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKStdL )
list(APPEND _cmake_import_check_files_for_TKStdL "${_IMPORT_PREFIX}/lib/libTKStdL.so.7.8.2" )

# Import target "TKTObj" for configuration "Release"
set_property(TARGET TKTObj APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(TKTObj PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libTKTObj.so.7.8.2"
  IMPORTED_SONAME_RELEASE "libTKTObj.so.7.8.2"
  )

list(APPEND _cmake_import_check_targets TKTObj )
list(APPEND _cmake_import_check_files_for_TKTObj "${_IMPORT_PREFIX}/lib/libTKTObj.so.7.8.2" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
